# Writer Python API library meta-package

This package is meta-package, which refers [writer-sdk](https://pypi.org/project/writer-sdk/) to provide aliasing. For further information follow [writer-sdk](https://pypi.org/project/writer-sdk/) PyPi web-page. 
